@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: value_custom.cc,v 1.1.1.1.2.1 2005/01/21 20:12:50 murrayc Exp $ */
+/* $Id: value_custom.cc 265 2006-04-12 12:50:12Z murrayc $ */
 
 /* Copyright 2002 The gtkmm Development Team
  *
@@ -26,7 +26,7 @@
 namespace
 {
 
-void warn_already_registered(const char* location, const std::string& full_name)
+static void warn_already_registered(const char* location, const std::string& full_name)
 {
   g_warning("file %s: (%s): The type name `%s' has been registered already.\n"
             "This is not supposed to happen -- please send a mail with detailed "
